pub struct ResourceBudget { /* private fields */ }Expand description
Shared, allocation-before-ownership resource budget.
Implementations
Sourceimpl ResourceBudget
impl ResourceBudget
Sourcepub fn from_options(options: StreamOptions) -> Self
pub fn from_options(options: StreamOptions) -> Self
Create a budget from public bounded-execution options.
Sourcepub fn new(memory_limit_bytes: u64, max_in_flight_batches: NonZeroUsize) -> Self
pub fn new(memory_limit_bytes: u64, max_in_flight_batches: NonZeroUsize) -> Self
Create a budget with a byte limit and a positive in-flight batch limit.
Sourcepub fn reserve(
&self,
scope: ResourceScope,
bytes: u64,
) -> Result<ResourceReservation>
pub fn reserve( &self, scope: ResourceScope, bytes: u64, ) -> Result<ResourceReservation>
Reserve byte ownership before allocating or retaining data.
Sourcepub fn reserve_batch(
&self,
scope: ResourceScope,
bytes: u64,
) -> Result<ResourceReservation>
pub fn reserve_batch( &self, scope: ResourceScope, bytes: u64, ) -> Result<ResourceReservation>
Reserve ownership for one decoded or retained batch before publishing it.
Sourcepub const fn memory_limit_bytes(&self) -> u64
pub const fn memory_limit_bytes(&self) -> u64
Return the configured byte limit.
Sourcepub const fn max_in_flight_batches(&self) -> usize
pub const fn max_in_flight_batches(&self) -> usize
Return the configured pipeline-owned batch limit.
Sourcepub fn usage(&self) -> ResourceUsage
pub fn usage(&self) -> ResourceUsage
Obtain an accounting snapshot for tests, diagnostics, and stream status.