pub struct StreamBatch { /* private fields */ }Expand description
Incremental batch source and stream contracts. A source-owned batch whose reservation remains held until consumer ownership transfer.
Implementations
Sourceimpl StreamBatch
impl StreamBatch
Sourcepub fn new(batch: RecordBatch, reservation: ResourceReservation) -> Self
pub fn new(batch: RecordBatch, reservation: ResourceReservation) -> Self
Attach the reservation acquired before the source published this batch.