pub type Result<T> = Result<T, DataFrameError>;Expand description
Re-export of the crate error type and result alias. Result type used throughout this crate.
Aliased Type
pub enum Result<T> {
Ok(T),
Err(DataFrameError),
}pub type Result<T> = Result<T, DataFrameError>;Re-export of the crate error type and result alias. Result type used throughout this crate.
pub enum Result<T> {
Ok(T),
Err(DataFrameError),
}