pub enum StreamingEligibility {
Supported {
source_limits: Vec<SourceLimit>,
},
Unsupported {
subject: PlanSubject,
reason: StreamingReason,
},
RequiresMaterialization {
subject: PlanSubject,
bounded_possible: bool,
},
}Expand description
Physical plan compiler and plan node types. Eligibility outcome returned before opening a source.
Variants
Supported
The compiler can construct a bounded source and per-batch pipeline.
Fields

source_limits: Vec<SourceLimit>Unsupported
No streaming implementation exists for this source or operator.
Fields

subject: PlanSubjectThe rejected source or operator.

reason: StreamingReasonStable reason code.
RequiresMaterialization
The operation is known but needs an explicit bounded materialization algorithm.
Fields

subject: PlanSubjectThe rejected operator.
Implementations
Sourceimpl StreamingEligibility
impl StreamingEligibility
Sourcepub fn into_result(self) -> Result<Vec<SourceLimit>>
pub fn into_result(self) -> Result<Vec<SourceLimit>>
Convert a non-supported result to its public preflight error.